@@ -2,26 +2,14 @@
  * Copyright © 2016-2018 The TokTok team.
  * Copyright © 2013-2015 Tox project.
  */
-#ifndef C_TOXCORE_TOXAV_TOXAV_H
-#define C_TOXCORE_TOXAV_TOXAV_H
 
-#include <stdbool.h>
-#include <stddef.h>
-#include <stdint.h>
-
-//!TOKSTYLE-
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/** \page av Public audio/video API for Tox clients.
+/** @file
+ * @brief Public audio/video API for Tox clients.
  *
  * This API can handle multiple calls. Each call has its state, in very rare
  * occasions the library can change the state of the call without apps knowledge.
  *
- */
-/** \subsection events Events and callbacks
+ * @section av_events Events and callbacks
  *
  * As in Core API, events are handled by callbacks. One callback can be
  * registered per event. All events have a callback function type named
@@ -33,15 +21,18 @@ extern "C" {
  * library to drop calls before they are started. Hanging up call from a
  * callback causes undefined behaviour.
  *
- */
-/** \subsection threading Threading implications
+ * @section av_threading Threading implications
  *
  * Only toxav_iterate is thread-safe, all other functions must run from the
  * tox thread.
  *
+ * Important exceptions are the `*_iterate` and `*_iterate_interval`
+ * functions. You have to choose either the single thread or the multi thread
+ * functions and read their documentation.
+ *
  * A common way to run ToxAV (multiple or single instance) is to have a thread,
  * separate from tox instance thread, running a simple toxav_iterate loop,
- * sleeping for toxav_iteration_interval * milliseconds on each iteration.
+ * sleeping for `toxav_iteration_interval * milliseconds` on each iteration.
  *
  * An important thing to note is that events are triggered from both tox and
  * toxav thread (see above). Audio and video receive frame events are triggered
@@ -50,7 +41,27 @@ extern "C" {
  * Tox thread has priority with mutex mechanisms. Any api function can
  * fail if mutexes are held by tox thread in which case they will set SYNC
  * error code.
+ *
+ * @subsection av_multi_threading Separate audio and video threads
+ *
+ * ToxAV supports either a single thread for audio and video or decoding and
+ * encoding them in separate threads. You have to choose one mode and can not
+ * mix function calls to those different modes.
+ *
+ * For best results use the multi-threaded mode and run the audio thread with
+ * higher priority than the video thread. This prioritizes audio over video.
  */
+#ifndef C_TOXCORE_TOXAV_TOXAV_H
+#define C_TOXCORE_TOXAV_TOXAV_H
+
+#include <stdbool.h>
+#include <stddef.h>
+#include <stdint.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /**
  * External Tox type.
  */
@@ -60,31 +71,22 @@ typedef struct Tox Tox;
 #endif /* TOX_DEFINED */
 
 /**
- * ToxAV.
- */
-/**
- * The ToxAV instance type. Each ToxAV instance can be bound to only one Tox
- * instance, and Tox instance can have only one ToxAV instance. One must make
- * sure to close ToxAV instance prior closing Tox instance otherwise undefined
- * behaviour occurs. Upon closing of ToxAV instance, all active calls will be
- * forcibly terminated without notifying peers.
+ * @brief The ToxAV instance type.
  *
+ * Each ToxAV instance can be bound to only one Tox  instance, and Tox instance
+ * can have only one ToxAV instance. One must make sure to close ToxAV instance
+ * prior closing Tox instance otherwise undefined behaviour occurs. Upon
+ * closing of ToxAV instance, all active calls will be forcibly terminated
+ * without notifying peers.
  */
-#ifndef TOXAV_DEFINED
-#define TOXAV_DEFINED
 typedef struct ToxAV ToxAV;
-#endif /* TOXAV_DEFINED */
 
 
-/*******************************************************************************
- *
- * :: Creation and destruction
- *
- ******************************************************************************/
+/** @{
+ * @brief Creation and destruction
+ */
 
-
-
-typedef enum TOXAV_ERR_NEW {
+typedef enum Toxav_Err_New {
 
     /**
      * The function returned successfully.
@@ -107,13 +109,13 @@ typedef enum TOXAV_ERR_NEW {
      */
     TOXAV_ERR_NEW_MULTIPLE,
 
-} TOXAV_ERR_NEW;
+} Toxav_Err_New;
 
 
 /**
  * Start new A/V session. There can only be only one session per Tox instance.
  */
-ToxAV *toxav_new(Tox *tox, TOXAV_ERR_NEW *error);
+ToxAV *toxav_new(Tox *tox, Toxav_Err_New *error);
 
 /**
  * Releases all resources associated with the A/V session.
@@ -129,38 +131,74 @@ void toxav_kill(ToxAV *av);
  */
 Tox *toxav_get_tox(const ToxAV *av);
 
-
-/*******************************************************************************
- *
- * :: A/V event loop
- *
- ******************************************************************************/
+/** @} */
 
 
+/** @{
+ * @brief A/V event loop, single thread
+ */
 
 /**
  * Returns the interval in milliseconds when the next toxav_iterate call should
  * be. If no call is active at the moment, this function returns 200.
+ * This function MUST be called from the same thread as toxav_iterate.
  */
 uint32_t toxav_iteration_interval(const ToxAV *av);
 
 /**
  * Main loop for the session. This function needs to be called in intervals of
- * toxav_iteration_interval() milliseconds. It is best called in the separate
+ * `toxav_iteration_interval()` milliseconds. It is best called in the separate
  * thread from tox_iterate.
  */
 void toxav_iterate(ToxAV *av);
 
-
-/*******************************************************************************
- *
- * :: Call setup
- *
- ******************************************************************************/
+/** @} */
 
 
+/** @{
+ * @brief A/V event loop, multiple threads
+ */
 
-typedef enum TOXAV_ERR_CALL {
+/**
+ * Returns the interval in milliseconds when the next toxav_audio_iterate call
+ * should be. If no call is active at the moment, this function returns 200.
+ * This function MUST be called from the same thread as toxav_audio_iterate.
+ */
+uint32_t toxav_audio_iteration_interval(const ToxAV *av);
+
+/**
+ * Main loop for the session. This function needs to be called in intervals of
+ * `toxav_audio_iteration_interval()` milliseconds. It is best called in a
+ * separate thread from tox_iterate and toxav_video_iterate. The thread calling
+ * this function should have higher priority than the one calling
+ * toxav_video_iterate to prioritize audio over video.
+ */
+void toxav_audio_iterate(ToxAV *av);
+
+/**
+ * Returns the interval in milliseconds when the next toxav_video_iterate call
+ * should be. If no call is active at the moment, this function returns 200.
+ * This function MUST be called from the same thread as toxav_video_iterate.
+ */
+uint32_t toxav_video_iteration_interval(const ToxAV *av);
+
+/**
+ * Main loop for the session. This function needs to be called in intervals of
+ * `toxav_video_iteration_interval()` milliseconds. It is best called in a
+ * separate thread from tox_iterate and toxav_audio_iterate. The thread calling
+ * this function should have lower priority than the one calling
+ * toxav_audio_iterate to prioritize audio over video.
+ */
+void toxav_video_iterate(ToxAV *av);
+
+/** @} */
+
+
+/** @{
+ * @brief Call setup
+ */
+
+typedef enum Toxav_Err_Call {
 
     /**
      * The function returned successfully.
@@ -199,7 +237,7 @@ typedef enum TOXAV_ERR_CALL {
      */
     TOXAV_ERR_CALL_INVALID_BIT_RATE,
 
-} TOXAV_ERR_CALL;
+} Toxav_Err_Call;
 
 
 /**
@@ -217,7 +255,7 @@ typedef enum TOXAV_ERR_CALL {
  * video sending.
  */
 bool toxav_call(ToxAV *av, uint32_t friend_number, uint32_t audio_bit_rate, uint32_t video_bit_rate,
-                TOXAV_ERR_CALL *error);
+                Toxav_Err_Call *error);
 
 /**
  * The function type for the call callback.
@@ -235,7 +273,7 @@ typedef void toxav_call_cb(ToxAV *av, uint32_t friend_number, bool audio_enabled
  */
 void toxav_callback_call(ToxAV *av, toxav_call_cb *callback, void *user_data);
 
-typedef enum TOXAV_ERR_ANSWER {
+typedef enum Toxav_Err_Answer {
 
     /**
      * The function returned successfully.
@@ -270,7 +308,7 @@ typedef enum TOXAV_ERR_ANSWER {
      */
     TOXAV_ERR_ANSWER_INVALID_BIT_RATE,
 
-} TOXAV_ERR_ANSWER;
+} Toxav_Err_Answer;
 
 
 /**
@@ -287,18 +325,16 @@ typedef enum TOXAV_ERR_ANSWER {
  * video sending.
  */
 bool toxav_answer(ToxAV *av, uint32_t friend_number, uint32_t audio_bit_rate, uint32_t video_bit_rate,
-                  TOXAV_ERR_ANSWER *error);
+                  Toxav_Err_Answer *error);
+
+/** @} */
 
 
-/*******************************************************************************
- *
- * :: Call state graph
- *
- ******************************************************************************/
+/** @{
+ * @brief Call state graph
+ */
 
-
-
-enum TOXAV_FRIEND_CALL_STATE {
+enum Toxav_Friend_Call_State {
 
     /**
      * The empty bit mask. None of the bits specified below are set.
@@ -361,16 +397,14 @@ typedef void toxav_call_state_cb(ToxAV *av, uint32_t friend_number, uint32_t sta
  */
 void toxav_callback_call_state(ToxAV *av, toxav_call_state_cb *callback, void *user_data);
 
-
-/*******************************************************************************
- *
- * :: Call control
- *
- ******************************************************************************/
+/** @} */
 
 
+/** @{
+ * @brief Call control
+ */
 
-typedef enum TOXAV_CALL_CONTROL {
+typedef enum Toxav_Call_Control {
 
     /**
      * Resume a previously paused call. Only valid if the pause was caused by this
@@ -413,10 +447,10 @@ typedef enum TOXAV_CALL_CONTROL {
      */
     TOXAV_CALL_CONTROL_SHOW_VIDEO,
 
-} TOXAV_CALL_CONTROL;
+} Toxav_Call_Control;
 
 
-typedef enum TOXAV_ERR_CALL_CONTROL {
+typedef enum Toxav_Err_Call_Control {
 
     /**
      * The function returned successfully.
@@ -445,7 +479,7 @@ typedef enum TOXAV_ERR_CALL_CONTROL {
      */
     TOXAV_ERR_CALL_CONTROL_INVALID_TRANSITION,
 
-} TOXAV_ERR_CALL_CONTROL;
+} Toxav_Err_Call_Control;
 
 
 /**
@@ -457,18 +491,16 @@ typedef enum TOXAV_ERR_CALL_CONTROL {
  *
  * @return true on success.
  */
-bool toxav_call_control(ToxAV *av, uint32_t friend_number, TOXAV_CALL_CONTROL control, TOXAV_ERR_CALL_CONTROL *error);
+bool toxav_call_control(ToxAV *av, uint32_t friend_number, Toxav_Call_Control control, Toxav_Err_Call_Control *error);
+
+/** @} */
 
 
-/*******************************************************************************
- *
- * :: Controlling bit rates
- *
- ******************************************************************************/
+/** @{
+ * @brief Controlling bit rates
+ */
 
-
-
-typedef enum TOXAV_ERR_BIT_RATE_SET {
+typedef enum Toxav_Err_Bit_Rate_Set {
 
     /**
      * The function returned successfully.
@@ -495,19 +527,17 @@ typedef enum TOXAV_ERR_BIT_RATE_SET {
      */
     TOXAV_ERR_BIT_RATE_SET_FRIEND_NOT_IN_CALL,
 
-} TOXAV_ERR_BIT_RATE_SET;
+} Toxav_Err_Bit_Rate_Set;
+
+/** @} */
 
 
 
-/*******************************************************************************
- *
- * :: A/V sending
- *
- ******************************************************************************/
+/** @{
+ * @brief A/V sending
+ */
 
-
-
-typedef enum TOXAV_ERR_SEND_FRAME {
+typedef enum Toxav_Err_Send_Frame {
 
     /**
      * The function returned successfully.
@@ -552,31 +582,31 @@ typedef enum TOXAV_ERR_SEND_FRAME {
      */
     TOXAV_ERR_SEND_FRAME_RTP_FAILED,
 
-} TOXAV_ERR_SEND_FRAME;
+} Toxav_Err_Send_Frame;
 
 
 /**
  * Send an audio frame to a friend.
  *
- * The expected format of the PCM data is: [s1c1][s1c2][...][s2c1][s2c2][...]...
+ * The expected format of the PCM data is: `[s1c1][s1c2][...][s2c1][s2c2][...]...`
  * Meaning: sample 1 for channel 1, sample 1 for channel 2, ...
  * For mono audio, this has no meaning, every sample is subsequent. For stereo,
  * this means the expected format is LRLRLR... with samples for left and right
  * alternating.
  *
  * @param friend_number The friend number of the friend to which to send an
- * audio frame.
+ *   audio frame.
  * @param pcm An array of audio samples. The size of this array must be
- * sample_count * channels.
+ *   `sample_count * channels`.
  * @param sample_count Number of samples in this frame. Valid numbers here are
- * ((sample rate) * (audio length) / 1000), where audio length can be
- * 2.5, 5, 10, 20, 40 or 60 millseconds.
+ *   `((sample rate) * (audio length) / 1000)`, where audio length can be
+ *   2.5, 5, 10, 20, 40 or 60 millseconds.
  * @param channels Number of audio channels. Supported values are 1 and 2.
  * @param sampling_rate Audio sampling rate used in this frame. Valid sampling
  * rates are 8000, 12000, 16000, 24000, or 48000.
  */
 bool toxav_audio_send_frame(ToxAV *av, uint32_t friend_number, const int16_t *pcm, size_t sample_count,
-                            uint8_t channels, uint32_t sampling_rate, TOXAV_ERR_SEND_FRAME *error);
+                            uint8_t channels, uint32_t sampling_rate, Toxav_Err_Send_Frame *error);
 
 /**
  * Set the bit rate to be used in subsequent video frames.
@@ -587,7 +617,7 @@ bool toxav_audio_send_frame(ToxAV *av, uint32_t friend_number, const int16_t *pc
  *
  * @return true on success.
  */
-bool toxav_audio_set_bit_rate(ToxAV *av, uint32_t friend_number, uint32_t bit_rate, TOXAV_ERR_BIT_RATE_SET *error);
+bool toxav_audio_set_bit_rate(ToxAV *av, uint32_t friend_number, uint32_t bit_rate, Toxav_Err_Bit_Rate_Set *error);
 
 /**
  * The function type for the audio_bit_rate callback. The event is triggered
@@ -610,9 +640,9 @@ void toxav_callback_audio_bit_rate(ToxAV *av, toxav_audio_bit_rate_cb *callback,
 /**
  * Send a video frame to a friend.
  *
- * Y - plane should be of size: height * width
- * U - plane should be of size: (height/2) * (width/2)
- * V - plane should be of size: (height/2) * (width/2)
+ * Y - plane should be of size: `height * width`
+ * U - plane should be of size: `(height/2) * (width/2)`
+ * V - plane should be of size: `(height/2) * (width/2)`
  *
  * @param friend_number The friend number of the friend to which to send a video
  * frame.
@@ -623,7 +653,7 @@ void toxav_callback_audio_bit_rate(ToxAV *av, toxav_audio_bit_rate_cb *callback,
  * @param v V (Chroma) plane data.
  */
 bool toxav_video_send_frame(ToxAV *av, uint32_t friend_number, uint16_t width, uint16_t height, const uint8_t *y,
-                            const uint8_t *u, const uint8_t *v, TOXAV_ERR_SEND_FRAME *error);
+                            const uint8_t *u, const uint8_t *v, Toxav_Err_Send_Frame *error);
 
 /**
  * Set the bit rate to be used in subsequent video frames.
@@ -634,7 +664,7 @@ bool toxav_video_send_frame(ToxAV *av, uint32_t friend_number, uint16_t width, u
  *
  * @return true on success.
  */
-bool toxav_video_set_bit_rate(ToxAV *av, uint32_t friend_number, uint32_t bit_rate, TOXAV_ERR_BIT_RATE_SET *error);
+bool toxav_video_set_bit_rate(ToxAV *av, uint32_t friend_number, uint32_t bit_rate, Toxav_Err_Bit_Rate_Set *error);
 
 /**
  * The function type for the video_bit_rate callback. The event is triggered
@@ -654,14 +684,12 @@ typedef void toxav_video_bit_rate_cb(ToxAV *av, uint32_t friend_number, uint32_t
  */
 void toxav_callback_video_bit_rate(ToxAV *av, toxav_video_bit_rate_cb *callback, void *user_data);
 
-
-/*******************************************************************************
- *
- * :: A/V receiving
- *
- ******************************************************************************/
+/** @} */
 
 
+/** @{
+ * @brief A/V receiving
+ */
 
 /**
  * The function type for the audio_receive_frame callback. The callback can be
@@ -669,7 +697,7 @@ void toxav_callback_video_bit_rate(ToxAV *av, toxav_video_bit_rate_cb *callback,
  * frames in the buffer. The received format is the same as in send function.
  *
  * @param friend_number The friend number of the friend who sent an audio frame.
- * @param pcm An array of audio samples (sample_count * channels elements).
+ * @param pcm An array of audio samples (`sample_count * channels` elements).
  * @param sample_count The number of audio samples per channel in the PCM array.
  * @param channels Number of audio channels.
  * @param sampling_rate Sampling rate used in this frame.
@@ -693,15 +721,15 @@ void toxav_callback_audio_receive_frame(ToxAV *av, toxav_audio_receive_frame_cb
  *
  * Strides represent padding for each plane that may or may not be present.
  * You must handle strides in your image processing code. Strides are
- * negative if the image is bottom-up hence why you MUST abs() it when
+ * negative if the image is bottom-up hence why you MUST `abs()` it when
  * calculating plane buffer size.
  *
  * @param friend_number The friend number of the friend who sent a video frame.
  * @param width Width of the frame in pixels.
  * @param height Height of the frame in pixels.
- * @param y Luminosity plane. Size = MAX(width, abs(ystride)) * height.
- * @param u U chroma plane. Size = MAX(width/2, abs(ustride)) * (height/2).
- * @param v V chroma plane. Size = MAX(width/2, abs(vstride)) * (height/2).
+ * @param y Luminosity plane. `Size = MAX(width, abs(ystride)) * height`.
+ * @param u U chroma plane. `Size = MAX(width/2, abs(ustride)) * (height/2)`.
+ * @param v V chroma plane. `Size = MAX(width/2, abs(vstride)) * (height/2)`.
  *
  * @param ystride Luminosity plane stride.
  * @param ustride U chroma plane stride.
@@ -718,49 +746,49 @@ typedef void toxav_video_receive_frame_cb(ToxAV *av, uint32_t friend_number, uin
  */
 void toxav_callback_video_receive_frame(ToxAV *av, toxav_video_receive_frame_cb *callback, void *user_data);
 
-/**
+/***
  * NOTE Compatibility with old toxav group calls. TODO(iphydf): remove
  *
  * TODO(iphydf): Use proper new API guidelines for these. E.g. don't use inline
  * function types, don't have per-callback userdata, especially don't have one
  * userdata per group.
  */
-/* Create a new toxav group.
- *
- * return group number on success.
- * return -1 on failure.
- *
- * Audio data callback format:
- *   audio_callback(Tox *tox, uint32_t groupnumber, uint32_t peernumber, const int16_t *pcm, unsigned int samples, uint8_t channels, uint32_t sample_rate, void *userdata)
- *
- * Note that total size of pcm in bytes is equal to (samples * channels * sizeof(int16_t)).
- */
-int toxav_add_av_groupchat(Tox *tox,
-                           void (*audio_callback)(void *, uint32_t, uint32_t, const int16_t *, unsigned int, uint8_t, uint32_t, void *),
-                           void *userdata);
 
-/* Join a AV group (you need to have been invited first.)
+// TODO(iphydf): Use this better typed one instead of the void-pointer one below.
+typedef void toxav_group_audio_cb(Tox *tox, uint32_t groupnumber, uint32_t peernumber, const int16_t *pcm,
+                                  uint32_t samples, uint8_t channels, uint32_t sample_rate, void *user_data);
+
+typedef void toxav_audio_data_cb(void *tox, uint32_t groupnumber, uint32_t peernumber, const int16_t *pcm,
+                                 uint32_t samples, uint8_t channels, uint32_t sample_rate, void *userdata);
+
+/** @brief Create a new toxav group.
  *
- * returns group number on success
- * returns -1 on failure.
+ * @return group number on success.
+ * @retval -1 on failure.
  *
- * Audio data callback format (same as the one for toxav_add_av_groupchat()):
- *   audio_callback(Tox *tox, uint32_t groupnumber, uint32_t peernumber, const int16_t *pcm, unsigned int samples, uint8_t channels, uint32_t sample_rate, void *userdata)
+ * Note that total size of pcm in bytes is equal to `samples * channels * sizeof(int16_t)`.
+ */
+int toxav_add_av_groupchat(Tox *tox, toxav_audio_data_cb *audio_callback, void *userdata);
+
+/** @brief Join a AV group (you need to have been invited first).
  *
- * Note that total size of pcm in bytes is equal to (samples * channels * sizeof(int16_t)).
+ * @return group number on success.
+ * @retval -1 on failure.
+ *
+ * Note that total size of pcm in bytes is equal to `samples * channels * sizeof(int16_t)`.
  */
 int toxav_join_av_groupchat(Tox *tox, uint32_t friendnumber, const uint8_t *data, uint16_t length,
-                            void (*audio_callback)(void *, uint32_t, uint32_t, const int16_t *, unsigned int, uint8_t, uint32_t, void *),
-                            void *userdata);
+                            toxav_audio_data_cb *audio_callback, void *userdata);
 
-/* Send audio to the group chat.
+/** @brief Send audio to the group chat.
  *
- * return 0 on success.
- * return -1 on failure.
+ * @retval 0 on success.
+ * @retval -1 on failure.
  *
- * Note that total size of pcm in bytes is equal to (samples * channels * sizeof(int16_t)).
+ * Note that total size of pcm in bytes is equal to `samples * channels * sizeof(int16_t)`.
  *
- * Valid number of samples are ((sample rate) * (audio length (Valid ones are: 2.5, 5, 10, 20, 40 or 60 ms)) / 1000)
+ * Valid number of samples are `(sample rate) * (audio length) / 1000`
+ *   (Valid values for audio length are: 2.5, 5, 10, 20, 40 or 60 ms)
  * Valid number of channels are 1 or 2.
  * Valid sample rates are 8000, 12000, 16000, 24000, or 48000.
  *
@@ -769,54 +797,53 @@ int toxav_join_av_groupchat(Tox *tox, uint32_t friendnumber, const uint8_t *data
 int toxav_group_send_audio(Tox *tox, uint32_t groupnumber, const int16_t *pcm, unsigned int samples, uint8_t channels,
                            uint32_t sample_rate);
 
-/* Enable A/V in a groupchat.
+/** @brief Enable A/V in a groupchat.
  *
  * A/V must be enabled on a groupchat for audio to be sent to it and for
  * received audio to be handled.
  *
- * An A/V group created with toxav_add_av_groupchat or toxav_join_av_groupchat
+ * An A/V group created with `toxav_add_av_groupchat` or `toxav_join_av_groupchat`
  * will start with A/V enabled.
  *
  * An A/V group loaded from a savefile will start with A/V disabled.
  *
- * return 0 on success.
- * return -1 on failure.
+ * @retval 0 on success.
+ * @retval -1 on failure.
  *
- * Audio data callback format (same as the one for toxav_add_av_groupchat()):
- *   audio_callback(Tox *tox, uint32_t groupnumber, uint32_t peernumber, const int16_t *pcm, unsigned int samples, uint8_t channels, uint32_t sample_rate, void *userdata)
- *
- * Note that total size of pcm in bytes is equal to (samples * channels * sizeof(int16_t)).
+ * Note that total size of pcm in bytes is equal to `samples * channels * sizeof(int16_t)`.
  */
 int toxav_groupchat_enable_av(Tox *tox, uint32_t groupnumber,
-                              void (*audio_callback)(void *, uint32_t, uint32_t, const int16_t *, unsigned int, uint8_t, uint32_t, void *),
-                              void *userdata);
+                              toxav_audio_data_cb *audio_callback, void *userdata);
 
-/* Disable A/V in a groupchat.
+/** @brief Disable A/V in a groupchat.
  *
- * return 0 on success.
- * return -1 on failure.
+ * @retval 0 on success.
+ * @retval -1 on failure.
  */
 int toxav_groupchat_disable_av(Tox *tox, uint32_t groupnumber);
 
-/* Return whether A/V is enabled in the groupchat.
- */
+/** @brief Return whether A/V is enabled in the groupchat. */
 bool toxav_groupchat_av_enabled(Tox *tox, uint32_t groupnumber);
 
+/** @} */
+
 #ifdef __cplusplus
 }
 #endif
 
-typedef void toxav_group_audio_cb(Tox *tox, uint32_t groupnumber, uint32_t peernumber, const int16_t *pcm,
-                                  uint32_t samples, uint8_t channels, uint32_t sample_rate, void *user_data);
+//!TOKSTYLE-
+#ifndef DOXYGEN_IGNORE
 
-typedef TOXAV_ERR_CALL Toxav_Err_Call;
-typedef TOXAV_ERR_NEW Toxav_Err_New;
-typedef TOXAV_ERR_ANSWER Toxav_Err_Answer;
-typedef TOXAV_ERR_CALL_CONTROL Toxav_Err_Call_Control;
-typedef TOXAV_ERR_BIT_RATE_SET Toxav_Err_Bit_Rate_Set;
-typedef TOXAV_ERR_SEND_FRAME Toxav_Err_Send_Frame;
-typedef TOXAV_CALL_CONTROL Toxav_Call_Control;
+typedef Toxav_Err_Call TOXAV_ERR_CALL;
+typedef Toxav_Err_New TOXAV_ERR_NEW;
+typedef Toxav_Err_Answer TOXAV_ERR_ANSWER;
+typedef Toxav_Err_Call_Control TOXAV_ERR_CALL_CONTROL;
+typedef Toxav_Err_Bit_Rate_Set TOXAV_ERR_BIT_RATE_SET;
+typedef Toxav_Err_Send_Frame TOXAV_ERR_SEND_FRAME;
+typedef Toxav_Call_Control TOXAV_CALL_CONTROL;
+typedef enum Toxav_Friend_Call_State TOXAV_FRIEND_CALL_STATE;
 
+#endif
 //!TOKSTYLE+
 
 #endif // C_TOXCORE_TOXAV_TOXAV_H
